# moncrud-leo
## using MongoDB with Mongoose and Express

Create a MongoDB Model and give it CRUD (Create, Read, Update, Delete) controls 
on an API route.


### Configure moncrud

```js
var mc = require('moncrud-leo');
// this depends on express, give the initializer the [app] element
mc.init(app, {
	//settings
	// more details will be available later
	apidomain: 'api',
	connection: 'mongodb://localhost/collection'
}, function(data, next){
	var hasAccess = true;
	//authenticate	
	/*
	 * data gives you details about the request,
	 */
	next(hasAccess); // true/false return 
	// this will return a response to the query based on a boolean.
	// if user is qualified after this test, the query is executed.
	// otherwise client get's an error response.
}); 
```

### Using moncrud

```js
// require moncrud
var mc = require('moncrud-leo');
// create a model
var users = mc.model('users', {
	firstname: String,
	lastname: String,
	email: String,
	active: Boolean,
	username: String,
	password: String,
	roles: ['basic'],
	friends: [{ 
		type: mc.ObjectId,
		ref: 'users'		
	}]
	// etc. Use the standard model parameters you would use for Mongoose	
});
// After the model is created, you can initate CRUD
// basic CRUD initializer:
users.crud();
// users.crud() function initiates HTTP\post calls: '/api/users/' [find, find-one, add, update, remove]
// you can also customoze the controller
users.crud({
	populate: {
		'get': ['friends'],
		'get-all': []				
	},
	custom: {
		'add-friend':function(req,res,model){
			// execute you standard calls here for a custom controller			
		}		
	}
		
});  

```

### This is a basic layout of the documention for this handy utility, more will come later.